# Rship-Python

Implementation of the rship SDK in Python. 

NOTES:

- Use __dict__ when providing a subclass as a property
- All MItem properties MUST be camelCase
- Time parameter for KeyframeArgs is in milliseconds
- Resolve to strings in models.py (proxies retain python objects)